@@ -4,7 +4,6 @@
 
 use std::{
     collections::{BTreeMap, BTreeSet},
-    convert::TryFrom,
     ffi::OsStr,
     io::Write,
     path::{Path, PathBuf},
@@ -271,6 +270,11 @@ impl FileEntry {
         self.link.as_deref()
     }
 
+    /// Set the target of a link.
+    pub fn set_link_target(&mut self, target: PathBuf) {
+        self.link = Some(target);
+    }
+
     /// Obtain a new instance guaranteed to have file data stored in memory.
     pub fn to_memory(&self) -> Result<Self, std::io::Error> {
         Ok(Self {
@@ -706,7 +710,10 @@ impl FileManifest {
 
 #[cfg(test)]
 mod tests {
-    use {super::*, tempfile::TempDir};
+    use super::*;
+
+    #[cfg(unix)]
+    use tempfile::TempDir;
 
     #[cfg(unix)]
     fn temp_dir() -> std::io::Result<TempDir> {
